==> notice-1.0.2.tar.gz: test/end_to_end_test.dart <==
import 'package:notice/notice.dart';
import 'package:notice/registry.dart';
import 'package:test/test.dart';

import 'custom_matchers.dart';
import 'history_output.dart';
import 'test_helpers.dart';

main() {
  group("end to end", () {
    test("simplest case", () {
      final history = HistoryOutput();
      final notice = Notice(outputs: [history]);
      final record = createTestRecord();
      notice.onRecord(record);
      expect(history.records, singleElement(record));
    });

    test("nested notices", () {
      final history = HistoryOutput();
      final parentNotice = Notice(outputs: [history]);
      final childNotice = Notice.childOf(parentNotice);
      final record = createTestRecord();
      childNotice.onRecord(record);
      expect(history.records, singleElement(record));
    });

    test("via registry", () => () {
      final registry = NoticeRegistry();
      final history = HistoryOutput();
      Notice(registries: [registry], outputs: [history]);
      final registeredNotice = Notice.childOf(registry);
      final record = createTestRecord();
      registeredNotice.onRecord(record);
      expect(history.records, singleElement(record));
    });

    test("breadcrumbs", () {
      final history = HistoryOutput();
      final notice = Notice(outputs: [history]);
      const childBreadcrumb = "child";
      final childNotice = Notice.childOf(notice, breadcrumb: childBreadcrumb);
      const grandchildBreadcrumb = "grandchild";
      final grandchildNotice = Notice.childOf(childNotice, breadcrumb: grandchildBreadcrumb);
      final record = createTestRecord();
      grandchildNotice.onRecord(record);
      final expectedRecord = record
        .copyWithBreadcrumb(grandchildBreadcrumb)
        .copyWithBreadcrumb(childBreadcrumb);
      expect(history.records, singleElement(expectedRecord));
    });
  });
}

==> notice-1.0.3.tar.gz: test/end_to_end_test.dart <==
import 'package:notice/notice.dart';
import 'package:notice/registry.dart';
import 'package:test/test.dart';

import 'custom_matchers.dart';
import 'history_output.dart';
import 'test_helpers.dart';

main() {
  group("end to end", () {
    test("simplest case", () {
      final history = HistoryOutput();
      final notice = Notice(outputs: [history]);
      final record = createTestRecord();
      notice.onRecord(record);
      expect(history.records, singleElement(record));
    });

    test("nested notices", () {
      final history = HistoryOutput();
      final parentNotice = Notice(outputs: [history]);
      final childNotice = Notice.childOf(parentNotice);
      final record = createTestRecord();
      childNotice.onRecord(record);
      expect(history.records, singleElement(record));
    });

    test("via registry", () {
      final registry = NoticeRegistry();
      final history = HistoryOutput();
      Notice(registries: [registry], outputs: [history]);
      final registeredNotice = Notice.childOf(registry);
      final record = createTestRecord();
      registeredNotice.onRecord(record);
      expect(history.records, singleElement(record));
    });

    test("breadcrumbs", () {
      final history = HistoryOutput();
      final notice = Notice(outputs: [history]);
      const childBreadcrumb = "child";
      final childNotice = Notice.childOf(notice, breadcrumb: childBreadcrumb);
      const grandchildBreadcrumb = "grandchild";
      final grandchildNotice =
          Notice.childOf(childNotice, breadcrumb: grandchildBreadcrumb);
      final record = createTestRecord();
      grandchildNotice.onRecord(record);
      final expectedRecord = record
          .copyWithBreadcrumb(grandchildBreadcrumb)
          .copyWithBreadcrumb(childBreadcrumb);
      expect(history.records, singleElement(expectedRecord));
    });
  });
}
